
.. blogpost::
    :title: Wordcloud to draw clouds of words
    :keywords: install, wordcloud
    :date: 2015-12-05
    :categories: install, module

    `wordcloud <https://github.com/amueller/word_cloud>`_
    is a nice module to draw `tag clouds <https://en.wikipedia.org/wiki/Tag_cloud>`_
    in Python. We can read the blog post
    `A Wordcloud in Python <http://peekaboo-vision.blogspot.de/2012/11/a-wordcloud-in-python.html>`_
    or see the `gallery <http://amueller.github.io/word_cloud/>`_.
    An example of what it can do:

    .. image:: http://amueller.github.io/word_cloud/_images/a_new_hope_1.png
